@@ -39,6 +39,7 @@
 #include "screen-review.h"
 #include <libxml/parser.h>
 
+
 gboolean login_time;
 
 static SRLClientHandle src_srl_client;
@@ -260,8 +261,8 @@ src_present_real_sro_for_speech (SRObject *obj, gchar *reason)
 	    if (srl_is_object_focused (obj) || strcmp (reason, "present") == 0 ||
 		strcmp (reason, "object:context-switched") == 0)
 	    {
-		if ( role == SR_ROLE_STATUS_BAR && strcmp (reason , "focus:") == 0)
-		    src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_SYSTEM, TRUE);
+		if (role == SR_ROLE_STATUS_BAR && strcmp (reason , "focus:") == 0)
+		    src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_WARNING, TRUE);
 		else if ((role == SR_ROLE_TABLE || role == SR_ROLE_TREE_TABLE) &&
 			strcmp (reason , "focus:") == 0)
 		    src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_IDLE, FALSE);
@@ -384,6 +385,8 @@ src_present_crt_window ()
     	{
 	    if (strcmp (reason, "window:create") == 0)
 		src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_WARNING, FALSE);
+	    else if (strcmp (reason, "window:rename") == 0)
+		src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_LOW, TRUE);
 	    else
 		src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_SYSTEM, TRUE);
 	}
